@@ -15,11 +15,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Dict, Iterable, Mapping, Optional, Union
+from typing import TYPE_CHECKING, Iterable, Mapping, Optional, Sequence, Union
 
 from airflow.models import BaseOperator
 from airflow.providers.neo4j.hooks.neo4j import Neo4jHook
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class Neo4jOperator(BaseOperator):
@@ -31,13 +33,14 @@ class Neo4jOperator(BaseOperator):
         :ref:`howto/operator:Neo4jOperator`
 
     :param sql: the sql code to be executed. Can receive a str representing a
-        sql statement, a list of str (sql statements)
-    :type sql: str or list[str]
-    :param neo4j_conn_id: reference to a specific Neo4j database
+        sql statement
+    :type sql: str
+    :param neo4j_conn_id: Reference to :ref:`Neo4j connection id <howto/connection:neo4j>`.
     :type neo4j_conn_id: str
     """
 
-    @apply_defaults
+    template_fields: Sequence[str] = ('sql',)
+
     def __init__(
         self,
         *,
@@ -50,13 +53,8 @@ class Neo4jOperator(BaseOperator):
         self.neo4j_conn_id = neo4j_conn_id
         self.sql = sql
         self.parameters = parameters
-        self.hook = None
 
-    def get_hook(self):
-        """Function to retrieve the Neo4j Hook."""
-        return Neo4jHook(conn_id=self.neo4j_conn_id)
-
-    def execute(self, context: Dict) -> None:
+    def execute(self, context: 'Context') -> None:
         self.log.info('Executing: %s', self.sql)
-        self.hook = self.get_hook()
-        self.hook.run(self.sql)
+        hook = Neo4jHook(conn_id=self.neo4j_conn_id)
+        hook.run(self.sql)
